==> hip-runtime-amd-5.3.0-1-x86_64.pkg.tar.zst: opt/rocm/hip/include/hip/nvidia_detail/nvidia_hip_unsafe_atomics.h <==
/*
    Copyright (c) 2022 Advanced Micro Devices, Inc. All rights reserved.

    Permission is hereby granted, free of charge, to any person obtaining a copy
    of this software and associated documentation files (the "Software"), to deal
    in the Software without restriction, including without limitation the rights
    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
    copies of the Software, and to permit persons to whom the Software is
    furnished to do so, subject to the following conditions:

    The above copyright notice and this permission notice shall be included in
    all copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
   THE SOFTWARE.
   */
#ifndef HIP_WRAPPER_INCLUDE_HIP_NVIDIA_DETAIL_NVIDIA_HIP_UNSAFE_ATOMICS_H
#define HIP_WRAPPER_INCLUDE_HIP_NVIDIA_DETAIL_NVIDIA_HIP_UNSAFE_ATOMICS_H

#pragma message("This file is deprecated. Use file from include path /opt/rocm-ver/include/ and prefix with hip")
#include "../../../../include/hip/nvidia_detail/nvidia_hip_unsafe_atomics.h"








#endif

==> hip-runtime-amd-5.4.0-2-x86_64.pkg.tar.zst: opt/rocm/hip/include/hip/nvidia_detail/nvidia_hip_unsafe_atomics.h <==
/*
    Copyright (c) 2022 Advanced Micro Devices, Inc. All rights reserved.

    Permission is hereby granted, free of charge, to any person obtaining a copy
    of this software and associated documentation files (the "Software"), to deal
    in the Software without restriction, including without limitation the rights
    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
    copies of the Software, and to permit persons to whom the Software is
    furnished to do so, subject to the following conditions:

    The above copyright notice and this permission notice shall be included in
    all copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
   THE SOFTWARE.
   */
#ifndef HIP_WRAPPER_INCLUDE_HIP_NVIDIA_DETAIL_NVIDIA_HIP_UNSAFE_ATOMICS_H
#define HIP_WRAPPER_INCLUDE_HIP_NVIDIA_DETAIL_NVIDIA_HIP_UNSAFE_ATOMICS_H

#pragma message("This file is deprecated. Use header files from HIP_PATH/include, where HIP_PATH corresponds to HIP install path")
#include "../../../../include/hip/nvidia_detail/nvidia_hip_unsafe_atomics.h"








#endif
